@@ -5,6 +5,8 @@ nplmodel <- function(y, weights = NULL, impact = NULL,
   type = c("2PL", "3PL", "3PLu", "4PL", "1PL", "RM"), grouppars = FALSE, vcov = TRUE,
   start = NULL, method = "BFGS", maxit = 500L, reltol = 1e-5, ...)
 {
+  ## original function call
+  mcall <- match.call()
 
   ## check for mirt
   if(!requireNamespace("mirt", quietly = TRUE)) {
@@ -279,7 +281,8 @@ nplmodel <- function(y, weights = NULL, impact = NULL,
     method = method,
     grouppars = grouppars,
     type = type,
-    mirt = model
+    mirt = model,
+    call = mcall
   )
   class(res) <- "nplmodel"
   return(res)
@@ -444,7 +447,8 @@ summary.nplmodel <- function(object, vcov. = NULL, ...)
 print.summary.nplmodel <- function(x, digits = max(3L, getOption("digits") - 3L),
   signif.stars = getOption("show.signif.stars"), ...)
 {
-  if(is.null(x$call)) {
+  show_call <- FALSE
+  if (is.null(x$call) || !show_call) {
     cat(sprintf("\n%s\n\n",
       if(x$type == "1PL") {
         "One parameter logistic model"
@@ -787,8 +791,7 @@ discrpar.nplmodel <- function(object, ref = NULL, alias = TRUE, vcov = TRUE, ...
     tmp <- vcov(object)
     if(object$type == "1PL") {
       a_var <- tmp[1L, 1L]
-      tmp <- matrix(1, N, N)
-      diag(tmp) <- a_var
+      tmp <- matrix(a_var, N, N)
     } else {
       tmp[grep("-a1$", rownames(tmp)), grep("-a1$", colnames(tmp))]
     }
@@ -858,7 +861,7 @@ discrpar.nplmodel <- function(object, ref = NULL, alias = TRUE, vcov = TRUE, ...
     }
   }
   rv <- structure(a, class = "discrpar", model = "PL", ref = ref,
-    alias = alias, vcov = vc)
+                  alias = alias, vcov = vc)
   return(rv)
 }
 
@@ -1295,9 +1298,9 @@ rpl <- function(theta, a = NULL, b, g = NULL, u = NULL, return_setting = TRUE)
   ## sample data under the model (in IRT formulation) given theta
   stopifnot(!is.null(theta) & !is.null(b))
   N <- length(b)
-  if (is.null(a)) a <- rep(1, length = N)
-  if (is.null(g)) g <- rep(0, length = N)
-  if (is.null(u)) u <- rep(1, length = N)
+  if (is.null(a)) a <- rep(1, length.out = N)
+  if (is.null(g)) g <- rep(0, length.out = N)
+  if (is.null(u)) u <- rep(1, length.out = N)
   stopifnot(all.equal(mode(a), mode(b), mode(g), mode(u)))
   if(is.list(theta)) {
     return(lapply(theta, rpl, a = a, b = b, g = g, u = u,
